//*********************************************************
//
// Copyright (c) Microsoft. All rights reserved.
//
//*********************************************************

using System;
using System.Collections.Generic;
using CustomTemperatureSensor;

namespace SDKTemplate
{
    public partial class MainPage : SDKTemplate.Common.LayoutAwarePage
    {
        // Change the string below to reflect the name of your sample.
        // This is used on the main page as the title of the sample.
        public const string FEATURE_NAME = "Custom Temperature Sensor";

        // Change the array below to reflect the name of your scenarios.
        // This will be used to populate the list of scenarios on the main page with
        // which the user will choose the specific scenario that they are interested in.
        // These should be in the form: "Navigating to a web page".
        // The code in MainPage will take care of turning this into: "1) Navigating to a web page"
        List<Scenario> scenarios = new List<Scenario>
        {
            new Scenario() { Title = "Connect to sensor", ClassType = typeof(DeviceConnect) },
            new Scenario() { Title = "Get temperature data", ClassType = typeof(InputReportEvents) },
            new Scenario() { Title = "Set report interval", ClassType = typeof(ReportInterval) }
        };
    }

    public class Scenario
    {
        public string Title { get; set; }

        public Type ClassType { get; set; }

        public override string ToString()
        {
            return Title;
        }
    }
}

namespace CustomTemperatureSensor
{
    public enum DeviceType
    {
        CustomSensor,
        Any,    // Can be any device
        None
    }

    public class OnDeviceConnectedEventArgs
    {
        private Boolean isDeviceSuccessfullyConnected;
        private Windows.Devices.Enumeration.DeviceInformation deviceInformation;

        public OnDeviceConnectedEventArgs(Boolean isDeviceSuccessfullyConnected, Windows.Devices.Enumeration.DeviceInformation deviceInformation)
        {
            this.isDeviceSuccessfullyConnected = isDeviceSuccessfullyConnected;
            this.deviceInformation = deviceInformation;
        }

        public Boolean IsDeviceSuccessfullyConnected
        {
            get
            {
                return isDeviceSuccessfullyConnected;
            }
        }

        public Windows.Devices.Enumeration.DeviceInformation DeviceInformation
        {
            get
            {
                return deviceInformation;
            }
        }
    }

    public class DeviceProperties
    {
        public const String DeviceInstanceId = "System.Devices.DeviceInstanceId";
    }

    /// <summary>
    ///          0x06,0x55,0xFF,     //HID_USAGE_PAGE_VENDOR_DEFINED
    ///          0x09,0xA5,          //HID_USAGE (vendor_defined)
    ///
    ///          0xA1,0x01,          //HID_COLLECTION(Application),
    ///
    ///          // Input report (device-transmits)
    ///          0x09,0xA7,          //HID_USAGE (vendor_defined)
    ///          0x15,0x00,          //HID_LOGICAL_MIN_8(0), // Minimum temp is 0 degrees F
    ///          0x25,0x96,          //HID_LOGICAL_MAX_8(1), // Max supported temp is 150 degrees F
    ///          0x75,0x08,          //HID_REPORT_SIZE(8),
    ///          0x95,0x01,          //HID_REPORT_COUNT(1),
    ///          0x81,0x02,          //HID_INPUT(Data_Var_Abs),
    ///
    ///          0x09,0xA8,          //HID_USAGE (vendor_defined)
    ///          0x15,0x4B,          //HID_LOGICAL_MIN_8(75),   // minimum 75 milliseconds
    ///          0x25,0xFF,          //HID_LOGICAL_MAX_8(255),  // maximum 255 milliseconds
    ///          0x75,0x08,          //HID_REPORT_SIZE(8), 
    ///          0x95,0x01,          //HID_REPORT_COUNT(1), 
    ///          0x81,0x02,          //HID_INPUT(Data_Var_Abs),
    ///
    ///          // Output report (device-receives)
    ///          0x09,0xA9,          //HID_USAGE (vendor_defined)
    ///          0x15,0x4B,          //HID_LOGICAL_MIN_8(75),   // minimum 75 milliseconds
    ///          0x25,0xFF,          //HID_LOGICAL_MAX_8(255),  // maximum 255 milliseconds
    ///          0x75,0x08,          //HID_REPORT_SIZE(8), 
    ///          0x95,0x01,          //HID_REPORT_COUNT(1), 
    ///          0x91,0x02,          //HID_OUTPUT(Data_Var_Abs),
    ///
    ///          0xC0                //HID_END_COLLECTION
    /// </summary>
 
    public class CustomSensor
    {

        public class Device
        {
            public const UInt16 Vid = 0x16C0;
            public const UInt16 Pid = 0x0012;
            public const UInt16 UsagePage = 0xFF55;
            public const UInt16 UsageId = 0xA5;
        }
    }
}
