//*********************************************************
//
// Copyright (c) Microsoft. All rights reserved.
//
//*********************************************************

using System;
using System.Collections.Generic;
using System.Globalization;
using System.Runtime.InteropServices.WindowsRuntime;
using System.Threading.Tasks;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;
using SDKTemplate;

namespace CustomTemperatureSensor
{
    /// <summary>
    /// This scenario demonstrates how to send output reports
    /// </summary>
    public sealed partial class ReportInterval : SDKTemplate.Common.LayoutAwarePage
    {
        // A pointer back to the main page.  This is needed if you want to call methods in MainPage such
        // as NotifyUser()
        private MainPage rootPage = MainPage.Current;

        public ReportInterval()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        ///
        /// We will enable/disable parts of the UI if the device doesn't support it.
        /// </summary>
        /// <param name="eventArgs">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs eventArgs)
        {
            // We will disable the scenario that is not supported by the device.
            // If no devices are connected, none of the scenarios will be shown and an error will be displayed
            Dictionary<DeviceType, UIElement> deviceScenarios = new Dictionary<DeviceType, UIElement>();
            deviceScenarios.Add(DeviceType.CustomSensor, CustomSensorScenario);

            Utilities.SetUpDeviceScenarios(deviceScenarios, DeviceScenarioContainer);
        }

        /// <summary>
        /// This method supports a minimum report interval of 75 milliseconds and a maximum report interval of 250 milliseconds.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="eventArgs"></param>
        private async void SetReportInterval_Click(Object sender, Windows.UI.Xaml.RoutedEventArgs eventArgs)
        {
            Byte valueToWrite = 0;

            ButtonSetReportInterval.IsEnabled = false;

            if (NumericValueToWrite.SelectedIndex == 0)
            { 
                valueToWrite = 75; 
            }
            if (NumericValueToWrite.SelectedIndex == 1)
            { 
                valueToWrite = 100; 
            }
            if (NumericValueToWrite.SelectedIndex == 2)
            { 
                valueToWrite = 150; 
            }
            if (NumericValueToWrite.SelectedIndex == 3)
            { 
                valueToWrite = 200; 
            }
            if (NumericValueToWrite.SelectedIndex == 4)
            { 
                valueToWrite = 250; 
            }
            await SetReportIntervalAsync(valueToWrite);
            ButtonSetReportInterval.IsEnabled = true;
        }


        /// <summary>
        /// The app sends an output report to the temperature sensor to request a new report interval.
        /// </summary>
        /// <param name="valueToWrite"></param>
        /// <returns>A task that can be used to chain more methods after completing the scenario</returns>
        private async Task SetReportIntervalAsync(Byte valueToWrite)
        {
            var outputReport = EventHandlerForDevice.Current.Device.CreateOutputReport();
            var dataWriter = new DataWriter();

            //First byte contains the report id
            dataWriter.WriteByte((Byte)outputReport.Id);
            dataWriter.WriteByte((Byte)valueToWrite);
            outputReport.Data = dataWriter.DetachBuffer();

            uint bytesWritten = await EventHandlerForDevice.Current.Device.SendOutputReportAsync(outputReport);

            rootPage.NotifyUser("Bytes written:  " + bytesWritten.ToString() + "; Value Written: " + valueToWrite.ToString(), NotifyType.StatusMessage);
        }
    }
}
